# Arikaim CMS services server



#### Requirements 
  * [Arikaim CMS](https://github.com/arikaim/arikaim)


#### Installation

```sh

pip install arikaim

```

#### Usage

##### Run

```sh

arikaim-server run

```

##### Create config file

```sh

arikaim-server config create

```
